@@ -420,6 +420,10 @@ public:
     }
 
     void visit_Function(const Function_t &x) {
+        if (ASRUtils::get_FunctionType(&x)->m_abi == abiType::Interactive) {
+            require(x.n_body == 0,
+            "The Function::n_body should be 0 if abi set to Interactive");
+        }
         std::vector<std::string> function_dependencies_copy = function_dependencies;
         function_dependencies.clear();
         function_dependencies.reserve(x.n_dependencies);
@@ -504,15 +508,15 @@ public:
         SymbolTable *parent_symtab = current_symtab;
         current_symtab = x.m_symtab;
         require(x.m_name != nullptr,
-            "The StructType::m_name cannot be nullptr");
+            "The Struct::m_name cannot be nullptr");
         require(x.m_symtab != nullptr,
-            "The StructType::m_symtab cannot be nullptr");
+            "The Struct::m_symtab cannot be nullptr");
         require(x.m_symtab->parent == parent_symtab,
-            "The StructType::m_symtab->parent is not the right parent");
+            "The Struct::m_symtab->parent is not the right parent");
         require(x.m_symtab->asr_owner == (ASR::asr_t*)&x,
             "The X::m_symtab::asr_owner must point to X");
         require(id_symtab_map.find(x.m_symtab->counter) == id_symtab_map.end(),
-            "StructType::m_symtab->counter must be unique");
+            "Struct::m_symtab->counter must be unique");
         require(ASRUtils::symbol_symtab(down_cast<symbol_t>(current_symtab->asr_owner)) == current_symtab,
             "The asr_owner invariant failed");
         id_symtab_map[x.m_symtab->counter] = x.m_symtab;
@@ -521,7 +525,7 @@ public:
             this->visit_symbol(*a.second);
             if( ASR::is_a<ASR::ClassProcedure_t>(*a.second) ||
                 ASR::is_a<ASR::GenericProcedure_t>(*a.second) ||
-                ASR::is_a<ASR::StructType_t>(*a.second) ||
+                ASR::is_a<ASR::Struct_t>(*a.second) ||
                 ASR::is_a<ASR::UnionType_t>(*a.second) ||
                 ASR::is_a<ASR::ExternalSymbol_t>(*a.second) ||
                 ASR::is_a<ASR::CustomOperator_t>(*a.second) ) {
@@ -532,17 +536,17 @@ public:
             ASR::ttype_t* var_type = ASRUtils::type_get_past_pointer(ASRUtils::symbol_type(a.second));
             char* aggregate_type_name = nullptr;
             ASR::symbol_t* sym = nullptr;
-            if( ASR::is_a<ASR::Struct_t>(*var_type) ) {
-                sym = ASR::down_cast<ASR::Struct_t>(var_type)->m_derived_type;
+            if( ASR::is_a<ASR::StructType_t>(*var_type) ) {
+                sym = ASR::down_cast<ASR::StructType_t>(var_type)->m_derived_type;
                 aggregate_type_name = ASRUtils::symbol_name(sym);
-            } else if( ASR::is_a<ASR::Enum_t>(*var_type) ) {
-                sym = ASR::down_cast<ASR::Enum_t>(var_type)->m_enum_type;
+            } else if( ASR::is_a<ASR::EnumType_t>(*var_type) ) {
+                sym = ASR::down_cast<ASR::EnumType_t>(var_type)->m_enum_type;
                 aggregate_type_name = ASRUtils::symbol_name(sym);
             } else if( ASR::is_a<ASR::Union_t>(*var_type) ) {
                 sym = ASR::down_cast<ASR::Union_t>(var_type)->m_union_type;
                 aggregate_type_name = ASRUtils::symbol_name(sym);
-            } else if( ASR::is_a<ASR::Class_t>(*var_type) ) {
-                sym = ASR::down_cast<ASR::Class_t>(var_type)->m_class_type;
+            } else if( ASR::is_a<ASR::ClassType_t>(*var_type) ) {
+                sym = ASR::down_cast<ASR::ClassType_t>(var_type)->m_class_type;
                 aggregate_type_name = ASRUtils::symbol_name(sym);
             }
             if( aggregate_type_name && ASRUtils::symbol_parent_symtab(sym) != current_symtab ) {
@@ -564,7 +568,7 @@ public:
         current_symtab = parent_symtab;
     }
 
-    void visit_StructType(const StructType_t& x) {
+    void visit_Struct(const Struct_t& x) {
         visit_UserDefinedType(x);
         if( !x.m_alignment ) {
             return ;
@@ -579,23 +583,23 @@ public:
                 " is not a positive power of 2.");
     }
 
-    void visit_EnumType(const EnumType_t& x) {
+    void visit_Enum(const Enum_t& x) {
         visit_UserDefinedType(x);
         require(x.m_type != nullptr,
-            "The common type of Enum cannot be nullptr. " +
+            "The common type of EnumType cannot be nullptr. " +
             std::string(x.m_name) + " doesn't seem to follow this rule.");
         ASR::ttype_t* common_type = x.m_type;
         std::map<int64_t, int64_t> value2count;
         for( auto itr: x.m_symtab->get_scope() ) {
             ASR::Variable_t* itr_var = ASR::down_cast<ASR::Variable_t>(itr.second);
             require(itr_var->m_symbolic_value != nullptr,
-                "All members of Enum must have their values to be set. " +
+                "All members of EnumType must have their values to be set. " +
                 std::string(itr_var->m_name) + " doesn't seem to follow this rule in "
-                + std::string(x.m_name) + " Enum.");
+                + std::string(x.m_name) + " EnumType.");
             require(ASRUtils::check_equal_type(itr_var->m_type, common_type),
-                "All members of Enum must the same type. " +
+                "All members of EnumType must the same type. " +
                 std::string(itr_var->m_name) + " doesn't seem to follow this rule in " +
-                std::string(x.m_name) + " Enum.");
+                std::string(x.m_name) + " EnumType.");
             ASR::expr_t* value = ASRUtils::expr_value(itr_var->m_symbolic_value);
             int64_t value_int64 = -1;
             ASRUtils::extract_value(value, value_int64);
@@ -629,7 +633,7 @@ public:
             is_enumtype_correct = !is_enum_integer;
         }
         require(is_enumtype_correct, "Properties of enum value members don't match correspond "
-                                     "to EnumType::m_enum_value_type");
+                                     "to Enum::m_enum_value_type");
     }
 
     void visit_UnionType(const UnionType_t& x) {
@@ -658,7 +662,7 @@ public:
             if (ASR::is_a<ASR::Module_t>(*asr_owner_sym)) {
                 is_module = true;
             }
-            if (ASR::is_a<ASR::StructType_t>(*asr_owner_sym)) {
+            if (ASR::is_a<ASR::Struct_t>(*asr_owner_sym)) {
                 is_struct = true;
             }
         }
@@ -714,8 +718,8 @@ public:
             require(std::string(x.m_original_name) == std::string(orig_name),
                 "ExternalSymbol::m_original_name must match external->m_name");
             ASR::Module_t *m = ASRUtils::get_sym_module(x.m_external);
-            ASR::StructType_t* sm = nullptr;
-            ASR::EnumType_t* em = nullptr;
+            ASR::Struct_t* sm = nullptr;
+            ASR::Enum_t* em = nullptr;
             ASR::UnionType_t* um = nullptr;
             ASR::Function_t* fm = nullptr;
             bool is_valid_owner = false;
@@ -723,15 +727,15 @@ public:
             std::string asr_owner_name = "";
             if( !is_valid_owner ) {
                 ASR::symbol_t* asr_owner_sym = ASRUtils::get_asr_owner(x.m_external);
-                is_valid_owner = (ASR::is_a<ASR::StructType_t>(*asr_owner_sym) ||
-                                  ASR::is_a<ASR::EnumType_t>(*asr_owner_sym) ||
+                is_valid_owner = (ASR::is_a<ASR::Struct_t>(*asr_owner_sym) ||
+                                  ASR::is_a<ASR::Enum_t>(*asr_owner_sym) ||
                                   ASR::is_a<ASR::Function_t>(*asr_owner_sym) ||
                                   ASR::is_a<ASR::UnionType_t>(*asr_owner_sym));
-                if( ASR::is_a<ASR::StructType_t>(*asr_owner_sym) ) {
-                    sm = ASR::down_cast<ASR::StructType_t>(asr_owner_sym);
+                if( ASR::is_a<ASR::Struct_t>(*asr_owner_sym) ) {
+                    sm = ASR::down_cast<ASR::Struct_t>(asr_owner_sym);
                     asr_owner_name = sm->m_name;
-                } else if( ASR::is_a<ASR::EnumType_t>(*asr_owner_sym) ) {
-                    em = ASR::down_cast<ASR::EnumType_t>(asr_owner_sym);
+                } else if( ASR::is_a<ASR::Enum_t>(*asr_owner_sym) ) {
+                    em = ASR::down_cast<ASR::Enum_t>(asr_owner_sym);
                     asr_owner_name = em->m_name;
                 } else if( ASR::is_a<ASR::UnionType_t>(*asr_owner_sym) ) {
                     um = ASR::down_cast<ASR::UnionType_t>(asr_owner_sym);
@@ -791,9 +795,9 @@ public:
             s = ASRUtils::symbol_get_past_external(x.m_v);
         }
         require(is_a<Variable_t>(*s) || is_a<Function_t>(*s)
-                || is_a<ASR::EnumType_t>(*s) || is_a<ASR::ExternalSymbol_t>(*s),
+                || is_a<ASR::Enum_t>(*s) || is_a<ASR::ExternalSymbol_t>(*s),
             "Var_t::m_v " + x_mv_name + " does not point to a Variable_t, " \
-            "Function_t, or EnumType_t (possibly behind ExternalSymbol_t)");
+            "Function_t, or Enum_t (possibly behind ExternalSymbol_t)");
         require(symtab_in_scope(current_symtab, x.m_v),
             "Var::m_v `" + x_mv_name + "` cannot point outside of its symbol table");
         variable_dependencies.push_back(x_mv_name);
@@ -890,11 +894,13 @@ public:
             require(x.m_new != x.m_old, "ArrayPhysicalCast is redundant, "
                 "the old physical type and new physical type must be different.");
         }
-        require(x.m_new == ASRUtils::extract_physical_type(x.m_type),
-            "Destination physical type conflicts with the physical type of target");
-        require(x.m_old == ASRUtils::extract_physical_type(ASRUtils::expr_type(x.m_arg)),
-            "Old physical type conflicts with the physical type of argument " + std::to_string(x.m_old)
-            + " " + std::to_string(ASRUtils::extract_physical_type(ASRUtils::expr_type(x.m_arg))));
+        if(check_external){
+            require(x.m_new == ASRUtils::extract_physical_type(x.m_type),
+                "Destination physical type conflicts with the physical type of target");
+            require(x.m_old == ASRUtils::extract_physical_type(ASRUtils::expr_type(x.m_arg)),
+                "Old physical type conflicts with the physical type of argument " + std::to_string(x.m_old)
+                + " " + std::to_string(ASRUtils::extract_physical_type(ASRUtils::expr_type(x.m_arg))));
+        }
     }
 
     void visit_SubroutineCall(const SubroutineCall_t &x) {
@@ -963,17 +969,17 @@ public:
         ASR::ttype_t *t2 = ASRUtils::type_get_past_pointer(ASRUtils::expr_type(dt));
         ASR::symbol_t *type_sym=nullptr;
         switch (t2->type) {
-            case (ASR::ttypeType::Struct): {
-                type_sym = ASR::down_cast<ASR::Struct_t>(t2)->m_derived_type;
+            case (ASR::ttypeType::StructType): {
+                type_sym = ASR::down_cast<ASR::StructType_t>(t2)->m_derived_type;
                 break;
             }
-            case (ASR::ttypeType::Class): {
-                type_sym = ASR::down_cast<ASR::Class_t>(t2)->m_class_type;
+            case (ASR::ttypeType::ClassType): {
+                type_sym = ASR::down_cast<ASR::ClassType_t>(t2)->m_class_type;
                 break;
             }
             default :
                 require_with_loc(false,
-                    "m_dt::m_v::m_type must point to a type with a symbol table (Struct or Class)",
+                    "m_dt::m_v::m_type must point to a type with a symbol table (StructType or ClassType)",
                     dt->base.loc);
         }
         return get_dt_symtab(type_sym);
@@ -982,15 +988,15 @@ public:
     ASR::symbol_t *get_parent_type_dt(ASR::symbol_t *dt) {
         ASR::symbol_t *parent = nullptr;
         switch (dt->type) {
-            case (ASR::symbolType::StructType): {
+            case (ASR::symbolType::Struct): {
                 dt = ASRUtils::symbol_get_past_external(dt);
-                ASR::StructType_t* der_type = ASR::down_cast<ASR::StructType_t>(dt);
+                ASR::Struct_t* der_type = ASR::down_cast<ASR::Struct_t>(dt);
                 parent = der_type->m_parent;
                 break;
             }
             default :
                 require_with_loc(false,
-                    "m_dt::m_v::m_type must point to a Struct type",
+                    "m_dt::m_v::m_type must point to a StructType type",
                     dt->base.loc);
         }
         return parent;
@@ -1001,25 +1007,25 @@ public:
         ASR::symbol_t *type_sym=nullptr;
         ASR::symbol_t *parent = nullptr;
         switch (t2->type) {
-            case (ASR::ttypeType::Struct): {
-                type_sym = ASR::down_cast<ASR::Struct_t>(t2)->m_derived_type;
+            case (ASR::ttypeType::StructType): {
+                type_sym = ASR::down_cast<ASR::StructType_t>(t2)->m_derived_type;
                 type_sym = ASRUtils::symbol_get_past_external(type_sym);
-                ASR::StructType_t* der_type = ASR::down_cast<ASR::StructType_t>(type_sym);
+                ASR::Struct_t* der_type = ASR::down_cast<ASR::Struct_t>(type_sym);
                 parent = der_type->m_parent;
                 break;
             }
-            case (ASR::ttypeType::Class): {
-                type_sym = ASR::down_cast<ASR::Class_t>(t2)->m_class_type;
+            case (ASR::ttypeType::ClassType): {
+                type_sym = ASR::down_cast<ASR::ClassType_t>(t2)->m_class_type;
                 type_sym = ASRUtils::symbol_get_past_external(type_sym);
-                if( type_sym->type == ASR::symbolType::StructType ) {
-                    ASR::StructType_t* der_type = ASR::down_cast<ASR::StructType_t>(type_sym);
+                if( type_sym->type == ASR::symbolType::Struct ) {
+                    ASR::Struct_t* der_type = ASR::down_cast<ASR::Struct_t>(type_sym);
                     parent = der_type->m_parent;
                 }
                 break;
             }
             default :
                 require_with_loc(false,
-                    "m_dt::m_v::m_type must point to a Struct type",
+                    "m_dt::m_v::m_type must point to a StructType type",
                     dt->base.loc);
         }
         return parent;
@@ -1128,13 +1134,13 @@ public:
         visit_ttype(*x.m_type);
     }
 
-    void visit_Struct(const Struct_t &x) {
+    void visit_StructType(const StructType_t &x) {
         std::string symbol_owner = "global scope";
         if( ASRUtils::get_asr_owner(x.m_derived_type) ) {
             symbol_owner = ASRUtils::symbol_name(ASRUtils::get_asr_owner(x.m_derived_type));
         }
         require(symtab_in_scope(current_symtab, x.m_derived_type),
-            "Struct::m_derived_type '" +
+            "StructType::m_derived_type '" +
             std::string(ASRUtils::symbol_name(x.m_derived_type)) +
             "' cannot point outside of its symbol table, owner: " +
             symbol_owner);
@@ -1161,16 +1167,20 @@ public:
 
     void visit_dimension(const dimension_t &x) {
         if (x.m_start) {
-            require_with_loc(ASRUtils::is_integer(
-                *ASRUtils::expr_type(x.m_start)),
-                "Start dimension must be a signed integer", x.loc);
+            if(check_external){
+                require_with_loc(ASRUtils::is_integer(
+                    *ASRUtils::expr_type(x.m_start)),
+                    "Start dimension must be a signed integer", x.loc);
+            }
             visit_expr(*x.m_start);
         }
 
         if (x.m_length) {
-            require_with_loc(ASRUtils::is_integer(
-                *ASRUtils::expr_type(x.m_length)),
-                "Length dimension must be a signed integer", x.loc);
+            if(check_external){
+                require_with_loc(ASRUtils::is_integer(
+                    *ASRUtils::expr_type(x.m_length)),
+                    "Length dimension must be a signed integer", x.loc);
+            }
             visit_expr(*x.m_length);
         }
     }
@@ -1209,11 +1219,13 @@ public:
     }
 
     void visit_Allocate(const Allocate_t &x) {
-        for( size_t i = 0; i < x.n_args; i++ ) {
-            require(ASR::is_a<ASR::Allocatable_t>(*ASRUtils::expr_type(x.m_args[i].m_a)) ||
-                    ASR::is_a<ASR::Pointer_t>(*ASRUtils::expr_type(x.m_args[i].m_a)),
-                "Allocate should only be called with  Allocatable or Pointer type inputs, found " +
-                std::string(ASRUtils::get_type_code(ASRUtils::expr_type(x.m_args[i].m_a))));
+        if(check_external){
+            for( size_t i = 0; i < x.n_args; i++ ) {
+                require(ASR::is_a<ASR::Allocatable_t>(*ASRUtils::expr_type(x.m_args[i].m_a)) ||
+                        ASR::is_a<ASR::Pointer_t>(*ASRUtils::expr_type(x.m_args[i].m_a)),
+                    "Allocate should only be called with  Allocatable or Pointer type inputs, found " +
+                    std::string(ASRUtils::get_type_code(ASRUtils::expr_type(x.m_args[i].m_a))));
+            }
         }
         BaseWalkVisitor<VerifyVisitor>::visit_Allocate(x);
     }
