@@ -227,8 +227,8 @@ public:
             } case ASR::ttypeType::Pointer: {
                 r = get_type(down_cast<ASR::Pointer_t>(t)->m_type) + ", pointer";
                 break;
-            } case ASR::ttypeType::Struct: {
-                ASR::Struct_t* struct_type = down_cast<ASR::Struct_t>(t);
+            } case ASR::ttypeType::StructType: {
+                ASR::StructType_t* struct_type = down_cast<ASR::StructType_t>(t);
                 std::string struct_name = ASRUtils::symbol_name(struct_type->m_derived_type);
                 r = "type(";
                 r += struct_name;
@@ -307,8 +307,8 @@ public:
         r += "\n";
         std::map<std::string, std::vector<std::string>> struct_dep_graph;
         for (auto &item : x.m_symtab->get_scope()) {
-            if (ASR::is_a<ASR::StructType_t>(*item.second) ||
-                    ASR::is_a<ASR::EnumType_t>(*item.second) ||
+            if (ASR::is_a<ASR::Struct_t>(*item.second) ||
+                    ASR::is_a<ASR::Enum_t>(*item.second) ||
                     ASR::is_a<ASR::UnionType_t>(*item.second)) {
                 std::vector<std::string> struct_deps_vec;
                 std::pair<char**, size_t> struct_deps_ptr = ASRUtils::symbol_dependencies(item.second);
@@ -388,8 +388,8 @@ public:
         }
         std::map<std::string, std::vector<std::string>> struct_dep_graph;
         for (auto &item : x.m_symtab->get_scope()) {
-            if (ASR::is_a<ASR::StructType_t>(*item.second) ||
-                    ASR::is_a<ASR::EnumType_t>(*item.second) ||
+            if (ASR::is_a<ASR::Struct_t>(*item.second) ||
+                    ASR::is_a<ASR::Enum_t>(*item.second) ||
                     ASR::is_a<ASR::UnionType_t>(*item.second)) {
                 std::vector<std::string> struct_deps_vec;
                 std::pair<char**, size_t> struct_deps_ptr = ASRUtils::symbol_dependencies(item.second);
@@ -599,7 +599,7 @@ public:
     void visit_ExternalSymbol(const ASR::ExternalSymbol_t &x) {
         ASR::symbol_t *sym = down_cast<ASR::symbol_t>(
             ASRUtils::symbol_parent_symtab(x.m_external)->asr_owner);
-        if (!is_a<ASR::StructType_t>(*sym)) {
+        if (!is_a<ASR::Struct_t>(*sym)) {
             src = indent;
             src += "use ";
             src.append(x.m_module_name);
@@ -609,7 +609,7 @@ public:
         }
     }
 
-    void visit_StructType(const ASR::StructType_t &x) {
+    void visit_Struct(const ASR::Struct_t &x) {
         std::string r = indent;
         r += "type :: ";
         r.append(x.m_name);
@@ -630,7 +630,7 @@ public:
         src = r;
     }
 
-    // void visit_EnumType(const ASR::EnumType_t &x) {}
+    // void visit_Enum(const ASR::Enum_t &x) {}
 
     // void visit_UnionType(const ASR::UnionType_t &x) {}
 
@@ -691,7 +691,7 @@ public:
         src = r;
     }
 
-    // void visit_ClassType(const ASR::ClassType_t &x) {}
+    // void visit_Class(const ASR::Class_t &x) {}
 
     // void visit_ClassProcedure(const ASR::ClassProcedure_t &x) {}
 
@@ -1183,7 +1183,7 @@ public:
         std::string re = src;
         visit_expr(*x.m_im);
         std::string im = src;
-        src = "(" + re + ", " + im + ")";
+        src = "cmplx(" + re + ", " + im + ")";
     }
 
     // void visit_NamedExpr(const ASR::NamedExpr_t &x) {}
@@ -1195,12 +1195,6 @@ public:
         } else {
             r += ASRUtils::symbol_name(x.m_name);
         }
-        if (r == "bit_size") {
-            // TODO: Remove this once bit_size is implemented in IntrinsicElementalFunction
-            visit_expr(*x.m_value);
-            return;
-        }
-
         r += "(";
         for (size_t i = 0; i < x.n_args; i ++) {
             visit_expr(*x.m_args[i].m_value);
@@ -1211,27 +1205,6 @@ public:
         src = r;
     }
 
-    void visit_TypeInquiry(const ASR::TypeInquiry_t &x) {
-        std::string out = "";
-        switch (x.m_inquiry_id) {
-            SET_INTRINSIC_NAME(Epsilon,   "epsilon"  );
-            SET_INTRINSIC_NAME(Huge,      "huge"     );
-            SET_INTRINSIC_NAME(Precision, "precision");
-            SET_INTRINSIC_NAME(Radix,     "radix"    );
-            SET_INTRINSIC_NAME(Range,     "range"    );
-            SET_INTRINSIC_NAME(Rank,      "rank"     );
-            SET_INTRINSIC_NAME(Tiny,      "tiny"     );
-            default : {
-                throw LCompilersException("TypeInquiry: `"
-                    + ASRUtils::get_intrinsic_name(x.m_inquiry_id)
-                    + "` is not implemented");
-            }
-        }
-        this->visit_expr(*x.m_arg);
-        out += "(" + src + ")";
-        src = out;
-    }
-
     void visit_IntrinsicImpureSubroutine( const ASR::IntrinsicImpureSubroutine_t &x ) {
         std::string out;
         out = "call ";
@@ -1253,79 +1226,72 @@ public:
         src = out;
     }
 
-    void visit_IntrinsicElementalFunction(const ASR::IntrinsicElementalFunction_t &x) {
-        std::string out;
-        switch (x.m_intrinsic_id) {
-            SET_INTRINSIC_NAME(Abs, "abs");
-            SET_INTRINSIC_NAME(Exp, "exp");
-            SET_INTRINSIC_NAME(Max, "max");
-            SET_INTRINSIC_NAME(Min, "min");
-            SET_INTRINSIC_NAME(Sqrt, "sqrt");
-            SET_INTRINSIC_NAME(Mod, "mod");
-            SET_INTRINSIC_NAME(Sin, "sin");
-            SET_INTRINSIC_NAME(Char, "char");
-            SET_INTRINSIC_NAME(StringContainsSet, "verify");
-            SET_INTRINSIC_NAME(StringFindSet, "scan");
-            SET_INTRINSIC_NAME(SubstrIndex, "index");
-            default : {
-                throw LCompilersException("IntrinsicElementalFunction: `"
-                    + ASRUtils::get_intrinsic_name(x.m_intrinsic_id)
-                    + "` is not implemented");
-            }
-        }
-        out += "(";
-        for (size_t i = 0; i < x.n_args; i ++) {
+    void visit_IntrinsicElementalFunction_helper(std::string &out, std::string func_name, const ASR::IntrinsicElementalFunction_t &x) {
+        out += func_name;
+        visit_expr(*x.m_args[0]);
+        out += "(" + src;
+        for (size_t i = 1; i < x.n_args; i++) {
+            out += ", ";
             visit_expr(*x.m_args[i]);
             out += src;
-            if (i < x.n_args-1) out += ", ";
         }
         out += ")";
         src = out;
     }
 
-    #define SET_ARR_INTRINSIC_NAME(X, func_name)                                \
-        case (static_cast<int64_t>(ASRUtils::IntrinsicArrayFunctions::X)) : {   \
-            visit_expr(*x.m_args[0]);                                           \
-            out += func_name; break;                                            \
-        }
-
-    void visit_IntrinsicArrayFunction(const ASR::IntrinsicArrayFunction_t &x) {
+    void visit_IntrinsicElementalFunction(const ASR::IntrinsicElementalFunction_t &x) {
         std::string out;
-        switch (x.m_arr_intrinsic_id) {
-            SET_ARR_INTRINSIC_NAME(Any, "any");
-            SET_ARR_INTRINSIC_NAME(Sum, "sum");
-            SET_ARR_INTRINSIC_NAME(Shape, "shape");
-            SET_ARR_INTRINSIC_NAME(MaxVal, "maxval");
-            SET_ARR_INTRINSIC_NAME(MinVal, "minval");
-            case (static_cast<int64_t>(ASRUtils::IntrinsicArrayFunctions::Pack)) : {
-                out += "pack";
-                visit_expr(*x.m_args[0]);
-                out += "(" + src + ", ";
-                visit_expr(*x.m_args[1]);
-                out += src;
-                if (x.n_args == 3) {
-                    out += ", ";
-                    visit_expr(*x.m_args[2]);
-                    out += src;
-                }
-                out += ")";
-                src = out;
-                out = "";
-                break;
-            }
-            default : {
-                throw LCompilersException("IntrinsicArrayFunction: `"
-                    + ASRUtils::get_array_intrinsic_name(x.m_arr_intrinsic_id)
-                    + "` is not implemented");
-            }
-        }
+        std::string intrinsic_func_name = ASRUtils::get_intrinsic_name(static_cast<int64_t>(x.m_intrinsic_id));
+        if(intrinsic_func_name == "StringFindSet") intrinsic_func_name = "scan";
+        else if(intrinsic_func_name == "StringContainsSet") intrinsic_func_name = "verify";
+        else if(intrinsic_func_name == "SubstrIndex") intrinsic_func_name = "index";
+        else if(intrinsic_func_name == "SelectedRealKind") intrinsic_func_name = "selected_real_kind";
+        else if(intrinsic_func_name == "SelectedIntKind") intrinsic_func_name = "selected_int_kind";
+        else if(intrinsic_func_name == "SelectedCharKind") intrinsic_func_name = "selected_char_kind";
+        else if(intrinsic_func_name == "LogGamma") intrinsic_func_name = "log_gamma";
+        else if(intrinsic_func_name == "SetExponent") intrinsic_func_name = "set_exponent";
+        else if(intrinsic_func_name == "Mergebits") intrinsic_func_name = "merge_bits";
+        visit_IntrinsicElementalFunction_helper(out, intrinsic_func_name, x);
+    }
+
+    void visit_TypeInquiry_helper(std::string &out, std::string func_name, const ASR::TypeInquiry_t &x) {
+        out += func_name;
+        visit_expr(*x.m_arg);
         out += "(" + src + ")";
         src = out;
     }
 
+    void visit_TypeInquiry(const ASR::TypeInquiry_t &x) {
+        std::string out;
+        std::string intrinsic_func_name = ASRUtils::get_intrinsic_name(static_cast<int64_t>(x.m_inquiry_id));
+        if(intrinsic_func_name == "BitSize") intrinsic_func_name = "bit_size";
+        else if(intrinsic_func_name == "NewLine") intrinsic_func_name = "new_line";
+        visit_TypeInquiry_helper(out, intrinsic_func_name, x);
+    }
+
+    void visit_IntrinsicArrayFunction_helper(std::string &out, std::string func_name, const ASR::IntrinsicArrayFunction_t &x) {
+        out += func_name;
+        visit_expr(*x.m_args[0]);
+        out += "(" + src;
+        for (size_t i = 1; i < x.n_args; i++) {
+            out += ", ";
+            visit_expr(*x.m_args[i]);
+            out += src;
+        }
+        out += ")";
+        src = out;
+    }
+
+    void visit_IntrinsicArrayFunction(const ASR::IntrinsicArrayFunction_t &x) {
+        std::string out;
+        std::string intrinsic_func_name = ASRUtils::get_array_intrinsic_name(static_cast<int64_t>(x.m_arr_intrinsic_id));
+        if(intrinsic_func_name == "DotProduct") intrinsic_func_name = "dot_product";
+        visit_IntrinsicArrayFunction_helper(out, intrinsic_func_name, x);
+    }
+
     // void visit_IntrinsicImpureFunction(const ASR::IntrinsicImpureFunction_t &x) {}
 
-    void visit_StructTypeConstructor(const ASR::StructTypeConstructor_t &x) {
+    void visit_StructConstructor(const ASR::StructConstructor_t &x) {
         std::string r = indent;
         r += ASRUtils::symbol_name(x.m_dt_sym);
         r += "(";
@@ -1338,11 +1304,17 @@ public:
         src = r;
     }
 
-    // void visit_EnumTypeConstructor(const ASR::EnumTypeConstructor_t &x) {}
+    // void visit_EnumConstructor(const ASR::EnumConstructor_t &x) {}
 
     // void visit_UnionTypeConstructor(const ASR::UnionTypeConstructor_t &x) {}
 
-    // void visit_ImpliedDoLoop(const ASR::ImpliedDoLoop_t &x) {}
+    void visit_ImpliedDoLoop(const ASR::ImpliedDoLoop_t &x) {
+        if (x.m_value) {
+            visit_expr(*x.m_value);
+            return;
+        }
+        return;
+    }
 
     void visit_IntegerConstant(const ASR::IntegerConstant_t &x) {
         src = std::to_string(x.m_n);
@@ -1398,9 +1370,9 @@ public:
     void visit_RealConstant(const ASR::RealConstant_t &x) {
         int kind = ASRUtils::extract_kind_from_ttype_t(x.m_type);
         if (kind >= 8) {
-            src = std::to_string(x.m_r) + "d0";
+            src = ASRUtils::to_string_with_precision(x.m_r, 16) + "_8";
         } else {
-            src = std::to_string(x.m_r);
+            src = ASRUtils::to_string_with_precision(x.m_r, 8);
         }
         last_expr_precedence = Precedence::Ext;
     }
@@ -1583,10 +1555,9 @@ public:
 
     void visit_ArrayConstant(const ASR::ArrayConstant_t &x) {
         std::string r = "[";
-        for(size_t i = 0; i < x.n_args; i++) {
-            visit_expr(*x.m_args[i]);
-            r += src;
-            if (i < x.n_args-1) r += ", ";
+        for(size_t i = 0; i < (size_t) ASRUtils::get_fixed_size_of_array(x.m_type); i++) {
+            r += ASRUtils::fetch_ArrayConstant_value(x, i);
+            if (i < (size_t) ASRUtils::get_fixed_size_of_array(x.m_type)-1) r += ", ";
         }
         r += "]";
         src = r;
@@ -1687,20 +1658,6 @@ public:
         src = r;
     }
 
-    void visit_ArrayAll(const ASR::ArrayAll_t &x) {
-        std::string r;
-        r += "all";
-        r += "(";
-        visit_expr(*x.m_mask);
-        r += src;
-        if (x.m_dim) {
-            visit_expr(*x.m_dim);
-            r += src;
-        }
-        r += ")";
-        src = r;
-    }
-
     // void visit_BitCast(const ASR::BitCast_t &x) {}
 
     void visit_StructInstanceMember(const ASR::StructInstanceMember_t &x) {
