@@ -38,34 +38,28 @@ intrinsic_funcs_args = {
             "ret_type_arg_idx": 0
         },
     ],
+    "Spacing": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
     "Modulo": [
         {
             "args": [("int", "int"), ("real", "real")],
             "ret_type_arg_idx": 0
         },
     ],
-    "BesselJ0": [
+    "BesselJN": [
         {
-            "args": [("real",)],
-            "ret_type_arg_idx": 0
+            "args": [("int", "real")],
+            "ret_type_arg_idx": 1
         },
     ],
-    "BesselJ1": [
+    "BesselYN": [
         {
-            "args": [("real",)],
-            "ret_type_arg_idx": 0
-        },
-    ],
-    "BesselY0": [
-        {
-            "args": [("real",)],
-            "ret_type_arg_idx": 0
-        },
-    ],
-    "BesselY1": [
-        {
-            "args": [("real",)],
-            "ret_type_arg_idx": 0
+            "args": [("int", "real")],
+            "ret_type_arg_idx": 1
         },
     ],
     "Mvbits": [
@@ -92,6 +86,78 @@ intrinsic_funcs_args = {
             "ret_type_arg_idx": 0
         }
     ],
+    "Trunc": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        }
+    ],
+    "Gamma": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        }
+    ],
+    "LogGamma": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        }
+    ],
+    "Log10": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        }
+    ],
+    "Erf": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        }
+    ],
+    "Erfc": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        }
+    ],
+    "Exp": [
+        {
+            "args": [("real",), ("complex",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "ErfcScaled": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "Atan2": [
+        {
+            "args": [("real", "real")],
+            "ret_type_arg_idx": 0
+        }
+    ],
+    "Fix": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        }
+    ],
+    "Exp2": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        }
+    ],
+    "Expm1": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        }
+    ],
     "SelectedIntKind": [
         {
             "args": [("int",)],
@@ -110,6 +176,13 @@ intrinsic_funcs_args = {
             "return": "int32"
         }
     ],
+    "Logical": [
+        {
+            "args": [("bool", )],
+            "ret_type_arg_idx": 0, 
+            "kind_arg": True
+        }
+    ],
     "Digits": [
         {
             "args": [("int",), ("real",)],
@@ -182,16 +255,22 @@ intrinsic_funcs_args = {
             "return": "int32"
         },
     ],
+    "Nearest": [
+        {
+            "args": [("real", "real")],
+            "ret_type_arg_idx": 0
+        },
+    ],
     "Adjustl": [
         {
             "args": [("char",)],
-            "return": "character(-1)"
+            "ret_type_arg_idx": 0
         }
     ],
     "Adjustr": [
         {
             "args": [("char",)],
-            "return": "character(-1)"
+            "ret_type_arg_idx": 0
         }
     ],
     "Aint": [
@@ -201,6 +280,12 @@ intrinsic_funcs_args = {
             "kind_arg": True
         }
     ],
+    "Isnan": [
+        {
+            "args": [("real",)],
+            "return": "logical",
+        }
+    ],
     "Nint": [
         {
             "args": [("real",)],
@@ -241,16 +326,142 @@ intrinsic_funcs_args = {
             "ret_type_arg_idx": 0
         }
     ],
+    "Atand": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        }
+    ],
+    "Sind": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        }
+    ],
+    "Cosd": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        }
+    ],
+    "Tand": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        }
+    ],
+    "BesselJ0": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "BesselJ1": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "BesselY0": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "BesselY1": [
+        {
+            "args": [("real",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
     "Sqrt": [
         {
             "args": [("real",), ("complex",)],
             "ret_type_arg_idx": 0
         },
     ],
+    "Sin": [
+        {
+            "args": [("real",), ("complex",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "Cos": [
+        {
+            "args": [("real",), ("complex",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "Tan": [
+        {
+            "args": [("real",), ("complex",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "Asin": [
+        {
+            "args": [("real",), ("complex",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "Acos": [
+        {
+            "args": [("real",), ("complex",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "Atan": [
+        {
+            "args": [("real",), ("complex",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "Sinh": [
+        {
+            "args": [("real",), ("complex",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "Cosh": [
+        {
+            "args": [("real",), ("complex",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "Tanh": [
+        {
+            "args": [("real",), ("complex",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "Asinh": [
+        {
+            "args": [("real",), ("complex",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "Acosh": [
+        {
+            "args": [("real",), ("complex",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "Atanh": [
+        {
+            "args": [("real",), ("complex",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
+    "Log": [
+        {
+            "args": [("real",), ("complex",)],
+            "ret_type_arg_idx": 0
+        },
+    ],
     "Sngl": [
         {
             "args": [("real",)],
-            "return": "real32"
+            "return": "real32",
         }
     ],
     "SignFromValue": [
@@ -398,6 +609,12 @@ intrinsic_funcs_args = {
             "kind_arg": True
         },
     ],
+    "Dreal": [
+        {
+            "args": [("complex64",)],
+            "return": "real64",
+        },
+    ],
     "Rank": [
         {
             "args": [("any",)],
@@ -407,7 +624,13 @@ intrinsic_funcs_args = {
     "BitSize": [
         {
             "args": [("int",)],
-            "return": "int32"
+            "ret_type_arg_idx": 0
+        }
+    ],
+    "NewLine": [
+        {
+            "args": [("char",)],
+            "return": "character(-1)"
         }
     ],
     "Range": [
@@ -478,6 +701,18 @@ intrinsic_funcs_args = {
             "kind_arg": True
         }
     ],
+    "Merge": [
+        {
+            "args": [("any", "any", "bool")],
+            "ret_type_arg_idx": 0
+        }
+    ],
+    "Mergebits": [
+        {
+            "args": [("int", "int", "int")],
+            "ret_type_arg_idx": 0
+        }
+    ], 
     "Ishftc": [
         {
             "args": [("int", "int")],
@@ -498,6 +733,13 @@ intrinsic_funcs_args = {
             "kind_arg": True
         }
     ],
+    "Achar": [
+        {
+            "args": [("int",)],
+            "return": "character(1)",
+            "kind_arg": True
+        }
+    ],
     "Exponent": [
         {
             "args": [("real",)],
@@ -528,6 +770,12 @@ intrinsic_funcs_args = {
            "ret_type_arg_idx": 0
        },
    ],
+   "Dshiftr": [
+       {
+           "args": [("int", "int", "int",)],
+           "ret_type_arg_idx": 0
+       },
+   ],
    "Popcnt": [
        {
            "args": [("int",)],
@@ -553,6 +801,8 @@ compile_time_only_fn = [
     "Tiny",
     "Huge",
     "BitSize",
+    "NewLine",
+    "Kind",
 ]
 
 type_to_asr_type_check = {
@@ -563,6 +813,7 @@ type_to_asr_type_check = {
     "bool": "is_logical",
     "char": "is_character",
     "complex": "is_complex",
+    "complex64": "is_complex<8>",
     "dict": "ASR::is_a<ASR::Dict_t>",
     "list": "ASR::is_a<ASR::List_t>",
     "tuple": "ASR::is_a<ASR::Tuple_t>"
@@ -679,12 +930,12 @@ def add_create_func_return_src(func_name):
     if kind_arg:
         src += indent * 2 + "if ( args[1] != nullptr ) {\n"
         src += indent * 3 +     "int kind = -1;\n"
-        src += indent * 3 +     "if (!ASR::is_a<ASR::Integer_t>(*expr_type(args[1])) || !extract_value(args[1], kind)) {\n"
+        src += indent * 3 +     "if (!ASR::is_a<ASR::Integer_t>(*expr_type(args[1])) || !extract_value(ASRUtils::expr_value(args[1]), kind)) {\n"
         src += indent * 4 +         f'append_error(diag, "`kind` argument of the `{func_name}` function must be a scalar Integer constant", args[1]->base.loc);\n'
         src += indent * 4 +         "return nullptr;\n"
         src += indent * 3 +     "}\n"
         src += indent * 3 +     "set_kind_to_ttype_t(return_type, kind);\n"
-        src += indent * 2 + "}\n"
+        src += indent * 2 + "}\n"        
     src += indent * 2 + "ASR::expr_t *m_value = nullptr;\n"
     src += indent * 2 + f"Vec<ASR::expr_t*> m_args; m_args.reserve(al, {no_of_args});\n"
     for _i in range(no_of_args):
@@ -692,16 +943,28 @@ def add_create_func_return_src(func_name):
     if func_name in compile_time_only_fn:
         src += indent * 2 + f"return_type = ASRUtils::extract_type(return_type);\n"
         src += indent * 2 + f"m_value = eval_{func_name}(al, loc, return_type, args, diag);\n"
+        src += indent * 3 +     "if (diag.has_error()) {\n"
+        src += indent * 4 +         f"return nullptr;\n"
+        src += indent * 3 +     "}\n"
         src += indent * 2 + "return ASR::make_TypeInquiry_t(al, loc, "\
             f"static_cast<int64_t>(IntrinsicElementalFunctions::{func_name}), "\
             "ASRUtils::expr_type(m_args[0]), m_args[0], return_type, m_value);\n"
 
     else:
+        if ret_type_val:
+            src += indent * 2 + "ASR::ttype_t* type = ASRUtils::expr_type(args[0]);\n"
+            src += indent * 2 + "if (ASR::is_a<ASR::Array_t>(*type)) {\n"
+            src += indent * 3 + "ASR::Array_t* e = ASR::down_cast<ASR::Array_t>(type);\n"
+            src += indent * 3 + f"return_type = TYPE(ASR::make_Array_t(al, type->base.loc, {ret_type_val}, e->m_dims, e->n_dims, ASR::array_physical_typeType::FixedSizeArray));\n"
+            src += indent * 2 + "}\n"
         src += indent * 2 + "if (all_args_evaluated(m_args)) {\n"
         src += indent * 3 +     f"Vec<ASR::expr_t*> args_values; args_values.reserve(al, {no_of_args});\n"
         for _i in range(no_of_args):
             src += indent * 3 + f"args_values.push_back(al, expr_value(m_args[{_i}]));\n"
         src += indent * 3 +     f"m_value = eval_{func_name}(al, loc, return_type, args_values, diag);\n"
+        src += indent * 3 +     "if (diag.has_error()) {\n"
+        src += indent * 4 +         f"return nullptr;\n"
+        src += indent * 3 +     "}\n"
         src += indent * 2 + "}\n"
         if "null" in intrinsic_funcs_ret_type.get(func_name, []):
             src += indent * 2 + f"return ASR::make_Expr_t(al, loc, ASRUtils::EXPR(ASR::make_IntrinsicElementalFunction_t(al, loc, static_cast<int64_t>(IntrinsicElementalFunctions::{func_name}), m_args.p, m_args.n, 0, return_type, m_value)));\n"
