@@ -16,7 +16,7 @@ namespace ASRUtils {
         return #X;                                                              \
     }
 
-inline std::string get_intrinsic_name(int x) {
+inline std::string get_intrinsic_name(int64_t x) {
     switch (x) {
         INTRINSIC_NAME_CASE(ObjectType)
         INTRINSIC_NAME_CASE(Kind)
@@ -27,6 +27,10 @@ inline std::string get_intrinsic_name(int x) {
         INTRINSIC_NAME_CASE(Asin)
         INTRINSIC_NAME_CASE(Asind)
         INTRINSIC_NAME_CASE(Acosd)
+        INTRINSIC_NAME_CASE(Atand)
+        INTRINSIC_NAME_CASE(Sind)
+        INTRINSIC_NAME_CASE(Cosd)
+        INTRINSIC_NAME_CASE(Tand)
         INTRINSIC_NAME_CASE(Acos)
         INTRINSIC_NAME_CASE(Atan)
         INTRINSIC_NAME_CASE(Sinh)
@@ -38,14 +42,17 @@ inline std::string get_intrinsic_name(int x) {
         INTRINSIC_NAME_CASE(Atanh)
         INTRINSIC_NAME_CASE(Erf)
         INTRINSIC_NAME_CASE(Erfc)
+        INTRINSIC_NAME_CASE(ErfcScaled)
         INTRINSIC_NAME_CASE(Gamma)
         INTRINSIC_NAME_CASE(Log)
         INTRINSIC_NAME_CASE(Log10)
+        INTRINSIC_NAME_CASE(Logical)
         INTRINSIC_NAME_CASE(LogGamma)
         INTRINSIC_NAME_CASE(Trunc)
         INTRINSIC_NAME_CASE(Fix)
         INTRINSIC_NAME_CASE(Abs)
         INTRINSIC_NAME_CASE(Aimag)
+        INTRINSIC_NAME_CASE(Dreal)
         INTRINSIC_NAME_CASE(Exp)
         INTRINSIC_NAME_CASE(Exp2)
         INTRINSIC_NAME_CASE(Expm1)
@@ -54,16 +61,24 @@ inline std::string get_intrinsic_name(int x) {
         INTRINSIC_NAME_CASE(FloorDiv)
         INTRINSIC_NAME_CASE(Mod)
         INTRINSIC_NAME_CASE(Trailz)
+        INTRINSIC_NAME_CASE(Isnan)
+        INTRINSIC_NAME_CASE(Nearest)
+        INTRINSIC_NAME_CASE(Spacing)
         INTRINSIC_NAME_CASE(Modulo)
         INTRINSIC_NAME_CASE(BesselJ0)
         INTRINSIC_NAME_CASE(BesselJ1)
+        INTRINSIC_NAME_CASE(BesselJN)
         INTRINSIC_NAME_CASE(BesselY0)
         INTRINSIC_NAME_CASE(BesselY1)
+        INTRINSIC_NAME_CASE(BesselYN)
         INTRINSIC_NAME_CASE(Mvbits)
+        INTRINSIC_NAME_CASE(Merge)
+        INTRINSIC_NAME_CASE(Mergebits)
         INTRINSIC_NAME_CASE(Shiftr)
         INTRINSIC_NAME_CASE(Rshift)
         INTRINSIC_NAME_CASE(Shiftl)
         INTRINSIC_NAME_CASE(Dshiftl)
+        INTRINSIC_NAME_CASE(Dshiftr)
         INTRINSIC_NAME_CASE(Ishft)
         INTRINSIC_NAME_CASE(Bgt)
         INTRINSIC_NAME_CASE(Blt)
@@ -93,6 +108,7 @@ inline std::string get_intrinsic_name(int x) {
         INTRINSIC_NAME_CASE(StringFindSet)
         INTRINSIC_NAME_CASE(SubstrIndex)
         INTRINSIC_NAME_CASE(Range)
+        INTRINSIC_NAME_CASE(Radix)
         INTRINSIC_NAME_CASE(Hypot)
         INTRINSIC_NAME_CASE(SelectedIntKind)
         INTRINSIC_NAME_CASE(SelectedRealKind)
@@ -101,6 +117,7 @@ inline std::string get_intrinsic_name(int x) {
         INTRINSIC_NAME_CASE(Adjustr)
         INTRINSIC_NAME_CASE(Ichar)
         INTRINSIC_NAME_CASE(Char)
+        INTRINSIC_NAME_CASE(Achar)
         INTRINSIC_NAME_CASE(MinExponent)
         INTRINSIC_NAME_CASE(MaxExponent)
         INTRINSIC_NAME_CASE(Ishftc)
@@ -136,6 +153,7 @@ inline std::string get_intrinsic_name(int x) {
         INTRINSIC_NAME_CASE(Precision)
         INTRINSIC_NAME_CASE(Tiny)
         INTRINSIC_NAME_CASE(BitSize)
+        INTRINSIC_NAME_CASE(NewLine)
         INTRINSIC_NAME_CASE(Conjg)
         INTRINSIC_NAME_CASE(Huge)
         INTRINSIC_NAME_CASE(Dprod)
@@ -176,69 +194,23 @@ namespace IntrinsicElementalFunctionRegistry {
         {static_cast<int64_t>(IntrinsicElementalFunctions::ObjectType),
             {nullptr, &ObjectType::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Gamma),
-            {&Gamma::instantiate_Gamma, &UnaryIntrinsicFunction::verify_args}},
+            {&Gamma::instantiate_Gamma, &Gamma::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Log10),
-            {&Log10::instantiate_Log10, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Log),
-            {&Log::instantiate_Log, &UnaryIntrinsicFunction::verify_args}},
+            {&Log10::instantiate_Log10, &Log10::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::LogGamma),
-            {&LogGamma::instantiate_LogGamma, &UnaryIntrinsicFunction::verify_args}},
+            {&LogGamma::instantiate_LogGamma, &LogGamma::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Erf),
-            {&Erf::instantiate_Erf, &UnaryIntrinsicFunction::verify_args}},
+            {&Erf::instantiate_Erf, &Erf::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Erfc),
-            {&Erfc::instantiate_Erfc, &UnaryIntrinsicFunction::verify_args}},
+            {&Erfc::instantiate_Erfc, &Erfc::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::ErfcScaled),
+            {&ErfcScaled::instantiate_ErfcScaled, &ErfcScaled::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Trunc),
-            {&Trunc::instantiate_Trunc, &UnaryIntrinsicFunction::verify_args}},
+            {&Trunc::instantiate_Trunc, &Trunc::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Fix),
-            {&Fix::instantiate_Fix, &UnaryIntrinsicFunction::verify_args}},
+            {&Fix::instantiate_Fix, &Fix::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Sin),
-            {&Sin::instantiate_Sin, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Cos),
-            {&Cos::instantiate_Cos, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Tan),
-            {&Tan::instantiate_Tan, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Asin),
-            {&Asin::instantiate_Asin, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Acos),
-            {&Acos::instantiate_Acos, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Atan),
-            {&Atan::instantiate_Atan, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Sinh),
-            {&Sinh::instantiate_Sinh, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Cosh),
-            {&Cosh::instantiate_Cosh, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Tanh),
-            {&Tanh::instantiate_Tanh, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Atan2),
-            {&Atan2::instantiate_Atan2, &BinaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Asinh),
-            {&Asinh::instantiate_Asinh, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Acosh),
-            {&Acosh::instantiate_Acosh, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Atanh),
-            {&Atanh::instantiate_Atanh, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Exp),
-            {&Exp::instantiate_Exp, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Exp2),
-            {nullptr, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Expm1),
-            {nullptr, &UnaryIntrinsicFunction::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::FMA),
-            {&FMA::instantiate_FMA, &FMA::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::FlipSign),
-            {&FlipSign::instantiate_FlipSign, &FlipSign::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::FloorDiv),
-            {&FloorDiv::instantiate_FloorDiv, &FloorDiv::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Mod),
-            {&Mod::instantiate_Mod, &Mod::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Asind),
-            {&Asind::instantiate_Asind, &Asind::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Acosd),
-            {&Acosd::instantiate_Acosd, &Acosd::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Trailz),
-            {&Trailz::instantiate_Trailz, &Trailz::verify_args}},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Modulo),
-            {&Modulo::instantiate_Modulo, &Modulo::verify_args}},
+            {&Sin::instantiate_Sin, &Sin::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::BesselJ0),
             {&BesselJ0::instantiate_BesselJ0, &BesselJ0::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::BesselJ1),
@@ -247,8 +219,80 @@ namespace IntrinsicElementalFunctionRegistry {
             {&BesselY0::instantiate_BesselY0, &BesselY0::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::BesselY1),
             {&BesselY1::instantiate_BesselY1, &BesselY1::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Asind),
+            {&Asind::instantiate_Asind, &Asind::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Acosd),
+            {&Acosd::instantiate_Acosd, &Acosd::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Atand),
+            {&Atand::instantiate_Atand, &Atand::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Sind),
+            {&Sind::instantiate_Sind, &Sind::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Cosd),
+            {&Cosd::instantiate_Cosd, &Cosd::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Tand),
+            {&Tand::instantiate_Tand, &Tand::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Cos),
+            {&Cos::instantiate_Cos, &Cos::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Tan),
+            {&Tan::instantiate_Tan, &Tan::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Asin),
+            {&Asin::instantiate_Asin, &Asin::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Acos),
+            {&Acos::instantiate_Acos, &Acos::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Atan),
+            {&Atan::instantiate_Atan, &Atan::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Sinh),
+            {&Sinh::instantiate_Sinh, &Sinh::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Cosh),
+            {&Cosh::instantiate_Cosh, &Cosh::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Tanh),
+            {&Tanh::instantiate_Tanh, &Tanh::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Atan2),
+            {&Atan2::instantiate_Atan2, &Atan2::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Asinh),
+            {&Asinh::instantiate_Asinh, &Asinh::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Acosh),
+            {&Acosh::instantiate_Acosh, &Acosh::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Atanh),
+            {&Atanh::instantiate_Atanh, &Atanh::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Log),
+            {&Log::instantiate_Log, &Log::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Logical),
+            {&Logical::instantiate_Logical, &Logical::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Exp),
+            {&Exp::instantiate_Exp, &Exp::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Exp2),
+            {nullptr, &Exp2::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Expm1),
+            {nullptr, &Expm1::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::FMA),
+            {&FMA::instantiate_FMA, &FMA::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::FlipSign),
+            {&FlipSign::instantiate_FlipSign, &FlipSign::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::FloorDiv),
+            {&FloorDiv::instantiate_FloorDiv, &FloorDiv::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Mod),
+            {&Mod::instantiate_Mod, &Mod::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Trailz),
+            {&Trailz::instantiate_Trailz, &Trailz::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Isnan),
+            {&Isnan::instantiate_Isnan, &Isnan::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Nearest),
+            {&Nearest::instantiate_Nearest, &Nearest::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Spacing),
+            {&Spacing::instantiate_Spacing, &Spacing::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Modulo),
+            {&Modulo::instantiate_Modulo, &Modulo::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::BesselJN),
+            {&BesselJN::instantiate_BesselJN, &BesselJN::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::BesselYN),
+            {&BesselYN::instantiate_BesselYN, &BesselYN::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Merge),
+            {&Merge::instantiate_Merge, &Merge::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Mvbits),
             {&Mvbits::instantiate_Mvbits, &Mvbits::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Mergebits),
+            {&Mergebits::instantiate_Mergebits, &Mergebits::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Shiftr),
             {&Shiftr::instantiate_Shiftr, &Shiftr::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Adjustl),
@@ -259,12 +303,16 @@ namespace IntrinsicElementalFunctionRegistry {
             {&Ichar::instantiate_Ichar, &Ichar::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Char),
             {&Char::instantiate_Char, &Char::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Achar),
+            {&Achar::instantiate_Achar, &Achar::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Rshift),
             {&Rshift::instantiate_Rshift, &Rshift::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Shiftl),
             {&Shiftl::instantiate_Shiftl, &Shiftl::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Dshiftl),
            {&Dshiftl::instantiate_Dshiftl, &Dshiftl::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Dshiftr),
+            {&Dshiftr::instantiate_Dshiftr, &Dshiftr::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Ishft),
             {&Ishft::instantiate_Ishft, &Ishft::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Bgt),
@@ -312,7 +360,7 @@ namespace IntrinsicElementalFunctionRegistry {
         {static_cast<int64_t>(IntrinsicElementalFunctions::Hypot),
             {&Hypot::instantiate_Hypot, &Hypot::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Kind),
-            {&Kind::instantiate_Kind, &Kind::verify_args}},
+            {nullptr, &Kind::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Rank),
             {nullptr, &Rank::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Digits),
@@ -335,6 +383,8 @@ namespace IntrinsicElementalFunctionRegistry {
             {&Abs::instantiate_Abs, &Abs::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Aimag),
             {&Aimag::instantiate_Aimag, &Aimag::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Dreal),
+            {&Dreal::instantiate_Dreal, &Dreal::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Partition),
             {&Partition::instantiate_Partition, &Partition::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::ListIndex),
@@ -409,6 +459,8 @@ namespace IntrinsicElementalFunctionRegistry {
             {nullptr, &UnaryIntrinsicFunction::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::BitSize),
             {nullptr, &UnaryIntrinsicFunction::verify_args}},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::NewLine),
+            {nullptr, &UnaryIntrinsicFunction::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Huge),
             {nullptr, &UnaryIntrinsicFunction::verify_args}},
         {static_cast<int64_t>(IntrinsicElementalFunctions::SelectedIntKind),
@@ -474,12 +526,16 @@ namespace IntrinsicElementalFunctionRegistry {
             "log"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Log10),
             "log10"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Logical),
+            "logical"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::LogGamma),
             "log_gamma"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Erf),
             "erf"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Erfc),
             "erfc"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::ErfcScaled),
+            "erfc_scaled"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Trunc),
             "trunc"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Fix),
@@ -514,6 +570,8 @@ namespace IntrinsicElementalFunctionRegistry {
             "abs"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Aimag),
             "aimag"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Dreal),
+            "dreal"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Exp),
             "exp"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Exp2),
@@ -526,22 +584,46 @@ namespace IntrinsicElementalFunctionRegistry {
             "floordiv"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Mod),
             "mod"},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Asind),
-            "asind"},
-        {static_cast<int64_t>(IntrinsicElementalFunctions::Acosd),
-            "acosd"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Trailz),
             "trailz"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Isnan),
+            "isnan"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Nearest),
+            "nearest"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Spacing),
+            "spacing"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Modulo),
             "modulo"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Asin),
+            "asind"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Acos),
+            "acosd"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Atan),
+            "atand"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Sind),
+            "sind"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Cosd),
+            "cosd"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Tand),
+            "tand"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::BesselJ0),
             "bessel_j0"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::BesselJ1),
+            "bessel_j1"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::BesselY0),
             "bessel_y0"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::BesselY1),
             "bessel_y1"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::BesselJN),
+            "bessel_jn"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::BesselYN),
+            "bessel_yn"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Merge),
+            "merge"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Mvbits),
             "mvbits"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Mergebits),
+            "mergebits"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Shiftr),
             "shiftr"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Rshift),
@@ -554,10 +636,14 @@ namespace IntrinsicElementalFunctionRegistry {
             "ichar"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Char),
             "char"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Achar),
+            "achar"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Shiftl),
             "shiftl"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Dshiftl),
            "dshiftl"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::Dshiftr),
+            "dshiftr"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Ishft),
             "ishft"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Bgt),
@@ -704,6 +790,8 @@ namespace IntrinsicElementalFunctionRegistry {
             "tiny"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::BitSize),
             "bit_size"},
+        {static_cast<int64_t>(IntrinsicElementalFunctions::NewLine),
+            "new_line"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::Huge),
             "huge"},
         {static_cast<int64_t>(IntrinsicElementalFunctions::SymbolicSymbol),
@@ -765,9 +853,20 @@ namespace IntrinsicElementalFunctionRegistry {
                 {"log_gamma", {&LogGamma::create_LogGamma, &LogGamma::eval_LogGamma}},
                 {"erf", {&Erf::create_Erf, &Erf::eval_Erf}},
                 {"erfc", {&Erfc::create_Erfc, &Erfc::eval_Erfc}},
+                {"erfc_scaled", {&ErfcScaled::create_ErfcScaled, &ErfcScaled::eval_ErfcScaled}},
                 {"trunc", {&Trunc::create_Trunc, &Trunc::eval_Trunc}},
                 {"fix", {&Fix::create_Fix, &Fix::eval_Fix}},
                 {"sin", {&Sin::create_Sin, &Sin::eval_Sin}},
+                {"bessel_j0", {&BesselJ0::create_BesselJ0, &BesselJ0::eval_BesselJ0}},
+                {"bessel_j1", {&BesselJ1::create_BesselJ1, &BesselJ1::eval_BesselJ1}},
+                {"bessel_y0", {&BesselY0::create_BesselY0, &BesselY0::eval_BesselY0}},
+                {"bessel_y1", {&BesselY1::create_BesselY1, &BesselY1::eval_BesselY1}},
+                {"asind", {&Asind::create_Asind, &Asind::eval_Asind}},
+                {"acosd", {&Acosd::create_Acosd, &Acosd::eval_Acosd}},
+                {"atand", {&Atand::create_Atand, &Atand::eval_Atand}},
+                {"sind", {&Sind::create_Sind, &Sind::eval_Sind}},
+                {"cosd", {&Cosd::create_Cosd, &Cosd::eval_Cosd}},
+                {"tand", {&Tand::create_Tand, &Tand::eval_Tand}},
                 {"cos", {&Cos::create_Cos, &Cos::eval_Cos}},
                 {"tan", {&Tan::create_Tan, &Tan::eval_Tan}},
                 {"asin", {&Asin::create_Asin, &Asin::eval_Asin}},
@@ -782,26 +881,30 @@ namespace IntrinsicElementalFunctionRegistry {
                 {"atanh", {&Atanh::create_Atanh, &Atanh::eval_Atanh}},
                 {"abs", {&Abs::create_Abs, &Abs::eval_Abs}},
                 {"aimag", {&Aimag::create_Aimag, &Aimag::eval_Aimag}},
+                {"dreal", {&Dreal::create_Dreal, &Dreal::eval_Dreal}},
                 {"exp", {&Exp::create_Exp, &Exp::eval_Exp}},
                 {"exp2", {&Exp2::create_Exp2, &Exp2::eval_Exp2}},
                 {"expm1", {&Expm1::create_Expm1, &Expm1::eval_Expm1}},
                 {"fma", {&FMA::create_FMA, &FMA::eval_FMA}},
                 {"floordiv", {&FloorDiv::create_FloorDiv, &FloorDiv::eval_FloorDiv}},
                 {"mod", {&Mod::create_Mod, &Mod::eval_Mod}},
-                {"asind", {&Asind::create_Asind, &Asind::eval_Asind}},
-                {"acosd", {&Acosd::create_Acosd, &Acosd::eval_Acosd}},
                 {"trailz", {&Trailz::create_Trailz, &Trailz::eval_Trailz}},
+                {"isnan", {&Isnan::create_Isnan, &Isnan::eval_Isnan}},
+                {"nearest", {&Nearest::create_Nearest, &Nearest::eval_Nearest}},
+                {"spacing", {&Spacing::create_Spacing, &Spacing::eval_Spacing}},
                 {"modulo", {&Modulo::create_Modulo, &Modulo::eval_Modulo}},
-                {"bessel_j0", {&BesselJ0::create_BesselJ0, &BesselJ0::eval_BesselJ0}},
-                {"bessel_j1", {&BesselJ1::create_BesselJ1, &BesselJ1::eval_BesselJ1}},
-                {"bessel_y0", {&BesselY0::create_BesselY0, &BesselY0::eval_BesselY0}},
-                {"bessel_y1", {&BesselY1::create_BesselY1, &BesselY1::eval_BesselY1}},
+                {"bessel_jn", {&BesselJN::create_BesselJN, &BesselJN::eval_BesselJN}},
+                {"bessel_yn", {&BesselYN::create_BesselYN, &BesselYN::eval_BesselYN}},
+                {"merge", {&Merge::create_Merge, &Merge::eval_Merge}},
                 {"mvbits", {&Mvbits::create_Mvbits, &Mvbits::eval_Mvbits}},
+                {"merge_bits", {&Mergebits::create_Mergebits, &Mergebits::eval_Mergebits}},
                 {"shiftr", {&Shiftr::create_Shiftr, &Shiftr::eval_Shiftr}},
                 {"rshift", {&Rshift::create_Rshift, &Rshift::eval_Rshift}},
                 {"shiftl", {&Shiftl::create_Shiftl, &Shiftl::eval_Shiftl}},
                 {"lshift", {&Shiftl::create_Shiftl, &Shiftl::eval_Shiftl}},
                 {"dshiftl", {&Dshiftl::create_Dshiftl, &Dshiftl::eval_Dshiftl}},
+                {"dshiftr", {&Dshiftr::create_Dshiftr, &Dshiftr::eval_Dshiftr}},
+                {"logical", {&Logical::create_Logical, &Logical::eval_Logical}},
                 {"ishft", {&Ishft::create_Ishft, &Ishft::eval_Ishft}},
                 {"bgt", {&Bgt::create_Bgt, &Bgt::eval_Bgt}},
                 {"blt", {&Blt::create_Blt, &Blt::eval_Blt}},
@@ -851,6 +954,7 @@ namespace IntrinsicElementalFunctionRegistry {
                 {"adjustr", {&Adjustr::create_Adjustr, &Adjustr::eval_Adjustr}},
                 {"ichar", {&Ichar::create_Ichar, &Ichar::eval_Ichar}},
                 {"char", {&Char::create_Char, &Char::eval_Char}},
+                {"achar", {&Achar::create_Achar, &Achar::eval_Achar}},
                 {"min0", {&Min::create_Min, &Min::eval_Min}},
                 {"max", {&Max::create_Max, &Max::eval_Max}},
                 {"min", {&Min::create_Min, &Min::eval_Min}},
@@ -878,6 +982,7 @@ namespace IntrinsicElementalFunctionRegistry {
                 {"precision", {&Precision::create_Precision, &Precision::eval_Precision}},
                 {"tiny", {&Tiny::create_Tiny, &Tiny::eval_Tiny}},
                 {"bit_size", {&BitSize::create_BitSize, &BitSize::eval_BitSize}},
+                {"new_line", {&NewLine::create_NewLine, &NewLine::eval_NewLine}},
                 {"conjg", {&Conjg::create_Conjg, &Conjg::eval_Conjg}},
                 {"huge", {&Huge::create_Huge, &Huge::eval_Huge}},
                 {"Symbol", {&SymbolicSymbol::create_SymbolicSymbol, &SymbolicSymbol::eval_SymbolicSymbol}},
@@ -1019,7 +1124,7 @@ namespace IntrinsicImpureFunctionRegistry {
         return #X;                                                              \
     }
 
-inline std::string get_impure_intrinsic_name(int x) {
+inline std::string get_impure_intrinsic_name(int64_t x) {
     switch (x) {
         IMPURE_INTRINSIC_NAME_CASE(IsIostatEnd)
         IMPURE_INTRINSIC_NAME_CASE(IsIostatEor)
@@ -1034,4 +1139,4 @@ inline std::string get_impure_intrinsic_name(int x) {
 
 } // namespace LCompilers
 
-#endif // LFORTRAN_PASS_INTRINSIC_FUNCTION_REGISTRY_H
+#endif // LFORTRAN_PASS_INTRINSIC_FUNCTION_REGISTRY_H
\ No newline at end of file
