@@ -246,73 +246,129 @@ void handle_logical(char* format, bool val, char** result) {
 void handle_float(char* format, double val, char** result) {
     int width = 0, decimal_digits = 0;
     long integer_part = (long)fabs(val);
-    double decimal_part = fabs(val) - labs(integer_part);
+    double decimal_part = fabs(val) - integer_part;
 
     int sign_width = (val < 0) ? 1 : 0;
-    int integer_length = (integer_part == 0) ? 1 : (int)log10(llabs(integer_part)) + 1;
+    int integer_length = (integer_part == 0) ? 1 : (int)log10(integer_part) + 1;
+
+    // parsing the format
+    char* dot_pos = strchr(format, '.');
+    if (dot_pos != NULL) {
+        decimal_digits = atoi(dot_pos + 1);
+        width = atoi(format + 1);
+    }
+
+    double rounding_factor = pow(10, -decimal_digits);
+    decimal_part = round(decimal_part / rounding_factor) * rounding_factor;
+
+    if (decimal_part >= 1.0) {
+        integer_part += 1;
+        decimal_part -= 1.0;
+    }
+
     char int_str[64];
     sprintf(int_str, "%ld", integer_part);
-    char dec_str[64];
+
     // TODO: This will work for up to `F65.60` but will fail for:
     // print "(F67.62)", 1.23456789101112e-62_8
-    sprintf(dec_str, "%.*lf", (60-integer_length), decimal_part);
-    memmove(dec_str,dec_str+2,strlen(dec_str));
+    char dec_str[64];
+    sprintf(dec_str, "%.*f", decimal_digits, decimal_part);
+    // removing the leading "0." from the formatted decimal part
+    memmove(dec_str, dec_str + 2, strlen(dec_str));
 
-    char* dot_pos = strchr(format, '.');
-    decimal_digits = atoi(++dot_pos);
-    width = atoi(format + 1);
-    if (dot_pos != NULL) {
-        if (width == 0) {
-            if (decimal_digits == 0) {
-                width = integer_length + sign_width + 1;
-            } else {
-                width = integer_length + sign_width + decimal_digits + 1;
-            }
-        }
+    // Determine total length needed
+    int total_length = sign_width + integer_length + 1 + decimal_digits;
+    if (width == 0) {
+        width = total_length;
     }
-    char formatted_value[64] = "";
-    int spaces = width - decimal_digits - sign_width - integer_length - 1;
+
+    char formatted_value[128] = "";
+    int spaces = width - total_length;
     for (int i = 0; i < spaces; i++) {
         strcat(formatted_value, " ");
     }
     if (val < 0) {
-        strcat(formatted_value,"-");
+        strcat(formatted_value, "-");
     }
-    if ((integer_part != 0 || (atoi(format + 1) != 0 || atoi(dot_pos) == 0))) {
-        strcat(formatted_value,int_str);
-    }
-    strcat(formatted_value,".");
-    if (decimal_part == 0) {
-        for(int i=0;i<decimal_digits;i++){
-            strcat(formatted_value, "0");
-        }
-    // TODO: figure out a way to round decimals with value < 1e-15
-    } else if (decimal_digits < strlen(dec_str) && decimal_digits <= 15) {
-        dec_str[15] = '\0';
-        int zeros = 0;
-        while(dec_str[zeros] == '0') zeros++;
-        long long t = (long long)round((double)atoll(dec_str) / (long long)pow(10, (strlen(dec_str) - decimal_digits)));
-        sprintf(dec_str, "%lld", t);
-        int index = zeros;
-        while(index--) strcat(formatted_value, "0");
-        strncat(formatted_value, dec_str, decimal_digits - zeros);
+    if (integer_part == 0 && format[1] == '0') {
+        strcat(formatted_value, "");
     } else {
-        dec_str[decimal_digits] = '\0';
-        strcat(formatted_value, dec_str);
-        for(int i=0;i<decimal_digits - strlen(dec_str);i++){
-            strcat(formatted_value, "0");
-        }
+        strcat(formatted_value, int_str);
     }
+    strcat(formatted_value, ".");
+    strcat(formatted_value, dec_str);
 
+    // checking for overflow
     if (strlen(formatted_value) > width) {
-        for(int i=0; i<width; i++){
-            *result = append_to_string(*result,"*");
+        for (int i = 0; i < width; i++) {
+            *result = append_to_string(*result, "*");
         }
     } else {
         *result = append_to_string(*result, formatted_value);
     }
 }
 
+/*
+`handle_en` - Formats a floating-point number using a Fortran-style "EN" format.
+
+NOTE: The function allocates memory for the formatted result, which is returned via
+the `result` parameter. It is the responsibility of the caller to free this memory
+using `free(*result)` after it is no longer needed.
+*/
+void handle_en(char* format, double val, int scale, char** result, char* c) {
+    int width, decimal_digits;
+    char *num_pos = format, *dot_pos = strchr(format, '.');
+    decimal_digits = atoi(++dot_pos);
+    while (!isdigit(*num_pos)) num_pos++;
+    width = atoi(num_pos);
+
+    // Calculate exponent
+    int exponent = 0;
+    if (val != 0.0) {
+        exponent = (int)floor(log10(fabs(val)));
+        int remainder = exponent % 3;
+        if (remainder < 0) remainder += 3;
+        exponent -= remainder;
+    }
+
+    double scaled_val = val / pow(10, exponent);
+
+    // Prepare value string
+    char val_str[128];
+    sprintf(val_str, "%.*lf", decimal_digits, scaled_val);
+
+    // Truncate unnecessary zeros
+    char* ptr = strchr(val_str, '.');
+    if (ptr) {
+        char* end_ptr = ptr;
+        while (*end_ptr != '\0') end_ptr++;
+        end_ptr--;
+        while (*end_ptr == '0' && end_ptr > ptr) end_ptr--;
+        *(end_ptr + 1) = '\0';
+    }
+
+    // Allocate a larger buffer
+    char formatted_value[256];  // Increased size to accommodate larger exponent values
+    int n = snprintf(formatted_value, sizeof(formatted_value), "%s%s%+03d", val_str, c, exponent);
+    if (n >= sizeof(formatted_value)) {
+        fprintf(stderr, "Error: output was truncated. Needed %d characters.\n", n);
+    }
+
+    // Handle width and padding
+    char* final_result = malloc(width + 1);
+    int padding = width - strlen(formatted_value);
+    if (padding > 0) {
+        memset(final_result, ' ', padding);
+        strcpy(final_result + padding, formatted_value);
+    } else {
+        strncpy(final_result, formatted_value, width);
+        final_result[width] = '\0';
+    }
+
+    // Assign the result to the output parameter
+    *result = final_result;
+}
+
 void handle_decimal(char* format, double val, int scale, char** result, char* c) {
     // Consider an example: write(*, "(es10.2)") 1.123e+10
     // format = "es10.2", val = 11230000128.00, scale = 0, c = "E"
@@ -484,6 +540,58 @@ void handle_decimal(char* format, double val, int scale, char** result, char* c)
     }
 }
 
+/*
+Ignore blank space characters within format specification, except
+within character string edit descriptor
+
+E.g.; "('Number : ', I 2, 5 X, A)" becomes '('Number : ', I2, 5X, A)'
+*/
+char* remove_spaces_except_quotes(const char* format) {
+    int len = strlen(format);
+    char* cleaned_format = malloc(len + 1);
+
+    int i = 0, j = 0;
+    // don't remove blank spaces from within character
+    // string editor descriptor
+    bool in_quotes = false;
+    char current_quote = '\0';
+
+    while (format[i] != '\0') {
+        char c = format[i];
+        if (c == '"' || c == '\'') {
+            if (i == 0 || format[i - 1] != '\\') {
+                // toggle in_quotes and set current_quote on entering or exiting quotes
+                if (!in_quotes) {
+                    in_quotes = true;
+                    current_quote = c;
+                } else if (current_quote == c) {
+                    in_quotes = false;
+                }
+            }
+        }
+
+        if (!isspace(c) || in_quotes) {
+            cleaned_format[j++] = c; // copy non-space characters or any character within quotes
+        }
+
+        i++;
+    }
+
+    cleaned_format[j] = '\0';
+    return cleaned_format;
+}
+
+/**
+ * parse fortran format string by extracting individual 'format specifiers'
+ * (e.g. 'i', 't', '*' etc.) into an array of strings
+ *
+ * `char* format`: the string we need to split into format specifiers
+ * `int* count`  : store count of format specifiers (passed by reference from caller)
+ * `item_start`  :
+ *
+ * e.g. "(I5, F5.2, T10)" is split separately into "I5", "F5.2", "T10" as
+ * format specifiers
+*/
 char** parse_fortran_format(char* format, int *count, int *item_start) {
     char** format_values_2 = (char**)malloc((*count + 1) * sizeof(char*));
     int format_values_count = *count;
@@ -528,9 +636,33 @@ char** parse_fortran_format(char* format, int *count, int *item_start) {
                 format_values_2[format_values_count++] = substring(format, start, index);
                 index--;
                 break;
+            case 'e' :
+                start = index++;
+                bool edot = false;
+                bool is_en_formatting = false;
+                if (tolower(format[index]) == 'n') {
+                    index++;  // move past the 'N'
+                    is_en_formatting = true;
+                }
+                if (tolower(format[index]) == 's') index++;
+                while (isdigit(format[index])) index++;
+                if (format[index] == '.') {
+                    edot = true;
+                    index++;
+                } else {
+                    printf("Error: Period required in format specifier\n");
+                    exit(1);
+                }
+                while (isdigit(format[index])) index++;
+                if (edot && (tolower(format[index]) == 'e' || tolower(format[index]) == 'n')) {
+                    index++;
+                    while (isdigit(format[index])) index++;
+                }
+                format_values_2[format_values_count++] = substring(format, start, index);
+                index--;
+                break;
             case 'i' :
             case 'd' :
-            case 'e' :
             case 'f' :
             case 'l' :
                 start = index++;
@@ -555,6 +687,19 @@ char** parse_fortran_format(char* format, int *count, int *item_start) {
                 format_values_2[format_values_count++] = substring(format, start, index+1);
                 *item_start = format_values_count;
                 break;
+            case 't' :
+                start = index++;
+                // raise error when "T" is specified itself or with non-positive width
+                if (!isdigit(format[index])) {
+                    printf("Error: Positive width required with 'T' descriptor in format string\n");
+                    exit(1);
+                }
+                while (isdigit(format[index])) {
+                    index++;
+                }
+                format_values_2[format_values_count++] = substring(format, start, index);
+                index--;
+                break;
             default :
                 if (
                     (format[index] == '-' && isdigit(format[index + 1]) && tolower(format[index + 2]) == 'p')
@@ -603,11 +748,16 @@ LFORTRAN_API char* _lcompilers_string_format_fortran(int count, const char* form
 {
     va_list args;
     va_start(args, format);
-    int len = strlen(format);
+    char* cleaned_format = remove_spaces_except_quotes(format);
+    if (!cleaned_format) {
+        va_end(args);
+        return NULL;
+    }
+    int len = strlen(cleaned_format);
     char* modified_input_string = (char*)malloc((len+1) * sizeof(char));
-    strncpy(modified_input_string, format, len);
+    strncpy(modified_input_string, cleaned_format, len);
     modified_input_string[len] = '\0';
-    if (format[0] == '(' && format[len-1] == ')') {
+    if (cleaned_format[0] == '(' && cleaned_format[len-1] == ')') {
         memmove(modified_input_string, modified_input_string + 1, strlen(modified_input_string));
         modified_input_string[len-2] = '\0';
     }
@@ -700,12 +850,19 @@ LFORTRAN_API char* _lcompilers_string_format_fortran(int count, const char* form
                 double val = va_arg(args, double);
                 handle_decimal(value, val, scale, &result, "D");
             } else if (tolower(value[0]) == 'e') {
-                // E Editing E[w[.d][Ee]]
-                // Only (E[w[.d]]) has been implemented yet
-                if ( count == 0 ) break;
-                count--;
-                double val = va_arg(args, double);
-                handle_decimal(value, val, scale, &result, "E");
+                // Check if the next character is 'N' for EN format
+                char format_type = tolower(value[1]);
+                if (format_type == 'n') {
+                    if (count == 0) break;
+                    count--;
+                    double val = va_arg(args, double);
+                    handle_en(value, val, scale, &result, "E");
+                } else {
+                    if (count == 0) break;
+                    count--;
+                    double val = va_arg(args, double);
+                    handle_decimal(value, val, scale, &result, "E");
+                }
             } else if (tolower(value[0]) == 'f') {
                 if ( count == 0 ) break;
                 count--;
@@ -717,6 +874,23 @@ LFORTRAN_API char* _lcompilers_string_format_fortran(int count, const char* form
                 char* val_str = va_arg(args, char*);
                 bool val = (strcmp(val_str, "True") == 0);
                 handle_logical(value, val, &result);
+            } else if (tolower(value[0]) == 't') {
+                if (count == 0) break;
+                int tab_position = atoi(value + 1);
+                int current_length = strlen(result);
+                int spaces_needed = tab_position - current_length - 1;
+                if (spaces_needed > 0) {
+                    char* spaces = (char*)malloc((spaces_needed + 1) * sizeof(char));
+                    memset(spaces, ' ', spaces_needed);
+                    spaces[spaces_needed] = '\0';
+                    result = append_to_string(result, spaces);
+                    free(spaces);
+                } else if (spaces_needed < 0) {
+                    // Truncate the string to the length specified by Tn if the current position exceeds it
+                    if (tab_position < current_length) {
+                        result[tab_position] = '\0';  // Truncate the string at the position specified by Tn
+                    }
+                }
             } else if (strlen(value) != 0) {
                 if ( count == 0 ) break;
                 count--;
@@ -923,11 +1097,11 @@ LFORTRAN_API double _lfortran_dlog(double x)
     return log(x);
 }
 
-LFORTRAN_API bool _lfortran_rsp_is_nan(float x) {
+LFORTRAN_API bool _lfortran_sis_nan(float x) {
     return isnan(x);
 }
 
-LFORTRAN_API bool _lfortran_rdp_is_nan(double x) {
+LFORTRAN_API bool _lfortran_dis_nan(double x) {
     return isnan(x);
 }
 
@@ -1003,44 +1177,64 @@ LFORTRAN_API double _lfortran_dlog_gamma(double x)
 
 // besselj0 --------------------------------------------------------------------
 
-LFORTRAN_API double _lfortran_dbesselj0( double x ) {
+LFORTRAN_API double _lfortran_dbessel_j0( double x ) {
     return j0(x);
 }
 
-LFORTRAN_API float _lfortran_sbesselj0( float x ) {
+LFORTRAN_API float _lfortran_sbessel_j0( float x ) {
     return j0(x);
 }
 
 // besselj1 --------------------------------------------------------------------
 
-LFORTRAN_API double _lfortran_dbesselj1( double x ) {
+LFORTRAN_API double _lfortran_dbessel_j1( double x ) {
     return j1(x);
 }
 
-LFORTRAN_API float _lfortran_sbesselj1( float x ) {
+LFORTRAN_API float _lfortran_sbessel_j1( float x ) {
     return j1(x);
 }
 
+// besseljn --------------------------------------------------------------------
+
+LFORTRAN_API double _lfortran_dbesseljn( int n, double x ) {
+    return jn(n, x);
+}
+
+LFORTRAN_API float _lfortran_sbesseljn( int n, float x ) {
+    return jn(n, x);
+}
+
 // bessely0 --------------------------------------------------------------------
 
-LFORTRAN_API double _lfortran_dbessely0( double x ) {
+LFORTRAN_API double _lfortran_dbessel_y0( double x ) {
     return y0(x);
 }
 
-LFORTRAN_API float _lfortran_sbessely0( float x ) {
+LFORTRAN_API float _lfortran_sbessel_y0( float x ) {
     return y0(x);
 }
 
 // bessely1 --------------------------------------------------------------------
 
-LFORTRAN_API double _lfortran_dbessely1( double x ) {
+LFORTRAN_API double _lfortran_dbessel_y1( double x ) {
     return y1(x);
 }
 
-LFORTRAN_API float _lfortran_sbessely1( float x ) {
+LFORTRAN_API float _lfortran_sbessel_y1( float x ) {
     return y1(x);
 }
 
+// besselyn --------------------------------------------------------------------
+
+LFORTRAN_API double _lfortran_dbesselyn( int n, double x ) {
+    return yn(n, x);
+}
+
+LFORTRAN_API float _lfortran_sbesselyn( int n, float x ) {
+    return yn(n, x);
+}
+
 // sin -------------------------------------------------------------------------
 
 LFORTRAN_API float _lfortran_ssin(float x)
@@ -1063,6 +1257,18 @@ LFORTRAN_API double_complex_t _lfortran_zsin(double_complex_t x)
     return csin(x);
 }
 
+LFORTRAN_API float _lfortran_ssind(float x)
+{
+    float radians = (x * PI) / 180.0;
+    return sin(radians);
+}
+
+LFORTRAN_API double _lfortran_dsind(double x)
+{
+    double radians = (x * PI) / 180.0;
+    return sin(radians);
+}
+
 // cos -------------------------------------------------------------------------
 
 LFORTRAN_API float _lfortran_scos(float x)
@@ -1085,6 +1291,18 @@ LFORTRAN_API double_complex_t _lfortran_zcos(double_complex_t x)
     return ccos(x);
 }
 
+LFORTRAN_API float _lfortran_scosd(float x)
+{
+    float radians = (x * PI) / 180.0;
+    return cos(radians);
+}
+
+LFORTRAN_API double _lfortran_dcosd(double x)
+{
+    double radians = (x * PI) / 180.0;
+    return cos(radians);
+}
+
 // tan -------------------------------------------------------------------------
 
 LFORTRAN_API float _lfortran_stan(float x)
@@ -1107,6 +1325,18 @@ LFORTRAN_API double_complex_t _lfortran_ztan(double_complex_t x)
     return ctan(x);
 }
 
+LFORTRAN_API float _lfortran_stand(float x)
+{
+    float radians = (x * PI) / 180.0;
+    return tan(radians);
+}
+
+LFORTRAN_API double _lfortran_dtand(double x)
+{
+    double radians = (x * PI) / 180.0;
+    return tan(radians);
+}
+
 // sinh ------------------------------------------------------------------------
 
 LFORTRAN_API float _lfortran_ssinh(float x)
@@ -1260,6 +1490,16 @@ LFORTRAN_API double_complex_t _lfortran_zatan(double_complex_t x)
     return catan(x);
 }
 
+LFORTRAN_API float _lfortran_satand(float x)
+{
+    return (atan(x)*180)/PI;
+}
+
+LFORTRAN_API double _lfortran_datand(double x)
+{
+    return (atan(x)*180)/PI;
+}
+
 // atan2 -----------------------------------------------------------------------
 
 LFORTRAN_API float _lfortran_satan2(float y, float x)
@@ -1852,10 +2092,14 @@ LFORTRAN_API int64_t _lfortran_ibits64(int64_t i, int32_t pos, int32_t len) {
 
 // cpu_time  -------------------------------------------------------------------
 
-LFORTRAN_API void _lfortran_cpu_time(double *t) {
+LFORTRAN_API void _lfortran_d_cpu_time(double *t) {
     *t = ((double) clock()) / CLOCKS_PER_SEC;
 }
 
+LFORTRAN_API void _lfortran_s_cpu_time(float *t) {
+    *t = ((float) clock()) / CLOCKS_PER_SEC;
+}
+
 // system_time -----------------------------------------------------------------
 
 LFORTRAN_API void _lfortran_i32sys_clock(
@@ -2091,8 +2335,6 @@ LFORTRAN_API int64_t _lfortran_open(int32_t unit_num, char *f_name, char *status
     if (streql(form, "formatted")) {
         unit_file_bin = false;
     } else if (streql(form, "unformatted")) {
-        // TODO: Handle unformatted write to a file
-        access_mode = "rb";
         unit_file_bin = true;
     } else {
         printf("Runtime error: FORM specifier in OPEN statement has "
@@ -2207,7 +2449,7 @@ LFORTRAN_API void _lfortran_read_int64(int64_t *p, int32_t unit_num)
 {
     if (unit_num == -1) {
         // Read from stdin
-        (void)!scanf(INT64, p);
+        (void)!scanf("%" PRId64, p);
         return;
     }
 
@@ -2221,7 +2463,7 @@ LFORTRAN_API void _lfortran_read_int64(int64_t *p, int32_t unit_num)
     if (unit_file_bin) {
         (void)!fread(p, sizeof(*p), 1, filep);
     } else {
-        (void)!fscanf(filep, INT64, p);
+        (void)!fscanf(filep, "%" PRId64, p);
     }
 }
 
@@ -2279,10 +2521,19 @@ LFORTRAN_API void _lfortran_read_array_int32(int32_t *p, int array_size, int32_t
 
 LFORTRAN_API void _lfortran_read_char(char **p, int32_t unit_num)
 {
+    const char SPACE = ' ';
+    int n = strlen(*p);
     if (unit_num == -1) {
         // Read from stdin
-        *p = (char*)malloc(strlen(*p) * sizeof(char));
-        (void)!scanf("%s", *p);
+        *p = (char*)malloc(n * sizeof(char));
+        (void)!fgets(*p, n + 1, stdin);
+        (*p)[strcspn(*p, "\n")] = 0;
+        size_t input_length = strlen(*p);
+        while (input_length < n) {
+            strncat(*p, &SPACE, 1);
+            input_length++;
+        }
+        (*p)[n] = '\0';
         return;
     }
 
@@ -2293,12 +2544,54 @@ LFORTRAN_API void _lfortran_read_char(char **p, int32_t unit_num)
         exit(1);
     }
 
-    int n = strlen(*p);
-    *p = (char*)malloc(n * sizeof(char));
     if (unit_file_bin) {
-        (void)!fread(*p, sizeof(char), n, filep);
+        // read the record marker for data length
+        int32_t data_length;
+        if (fread(&data_length, sizeof(int32_t), 1, filep) != 1) {
+            printf("Error reading data length from file.\n");
+            exit(1);
+        }
+
+        // allocate memory for the data based on data length
+        *p = (char*)malloc((data_length + 1) * sizeof(char));
+        if (*p == NULL) {
+            printf("Memory allocation failed.\n");
+            exit(1);
+        }
+
+        // read the actual data
+        if (fread(*p, sizeof(char), data_length, filep) != data_length) {
+            printf("Error reading data from file.\n");
+            free(*p);
+            exit(1);
+        }
+        (*p)[data_length] = '\0';
+
+        // read the record marker after data
+        int32_t check_length;
+        if (fread(&check_length, sizeof(int32_t), 1, filep) != 1) {
+            printf("Error reading end data length from file.\n");
+            free(*p);
+            exit(1);
+        }
+
+        // verify that the start and end markers match
+        if (check_length != data_length) {
+            printf("Data length mismatch between start and end markers.\n");
+            free(*p);
+            exit(1);
+        }
     } else {
-        (void)!fscanf(filep, "%s", *p);
+        char *tmp_buffer = (char*)malloc((n + 1) * sizeof(char));
+        (void)!fscanf(filep, "%s", tmp_buffer);
+        size_t input_length = strlen(tmp_buffer);
+        strcpy(*p, tmp_buffer);
+        free(tmp_buffer);
+        while (input_length < n) {
+            strncat(*p, &SPACE, 1);
+            input_length++;
+        }
+        (*p)[n] = '\0';
     }
     if (streql(*p, "")) {
         printf("Runtime error: End of file!\n");
@@ -2525,16 +2818,44 @@ LFORTRAN_API void _lfortran_file_write(int32_t unit_num, int32_t* iostat, const
         filep = stdout;
     }
     if (unit_file_bin) {
-        printf("Binary content is not handled by write(..)\n");
-        exit(1);
-    }
-    va_list args;
-    va_start(args, format);
-    vfprintf(filep, format, args);
-    va_end(args);
+        va_list args;
+        va_start(args, format);
+        const char* str = va_arg(args, const char*);
+        // size the size of `str_len` to bytes
+        size_t str_len = strlen(str);
 
+        // calculate record marker size
+        int32_t record_marker = (int32_t)str_len;
+
+        // write record marker before the data
+        fwrite(&record_marker, sizeof(record_marker), 1, filep);
+
+        size_t written = fwrite(str, sizeof(char), str_len, filep); // write as binary data
+
+        // write the record marker after the data
+        fwrite(&record_marker, sizeof(record_marker), 1, filep);
+
+        if (written != str_len) {
+            printf("Error writing data to file.\n");
+            // TODO: not sure what is the right value of "iostat" in this case
+            // it should be a positive value unique from other predefined iostat values
+            // like IOSTAT_INQUIRE_INTERNAL_UNIT, IOSTAT_END, and IOSTAT_EOR.
+            // currently, I've set it to 11
+            *iostat = 11;
+            exit(1);
+        } else {
+            *iostat = 0;
+        }
+
+        va_end(args);
+    } else {
+        va_list args;
+        va_start(args, format);
+        vfprintf(filep, format, args);
+        va_end(args);
+        *iostat = 0;
+    }
     (void)!ftruncate(fileno(filep), ftell(filep));
-    *iostat = 0;
 }
 
 LFORTRAN_API void _lfortran_string_write(char **str, int32_t* iostat, const char *format, ...) {
@@ -2584,15 +2905,6 @@ LFORTRAN_API int32_t _lfortran_iachar(char *c) {
     return (int32_t) (uint8_t)(c[0]);
 }
 
-LFORTRAN_API int32_t _lfortran_all(bool *mask, int32_t n) {
-    for (size_t i = 0; i < n; i++) {
-        if (!mask[i]) {
-            return false;
-        }
-    }
-    return true;
-}
-
 // Command line arguments
 int32_t _argc;
 char **_argv;
